@@ -90,6 +90,9 @@ sub profile_default
 		topItem        => 0,
 		offset         => 0,
 		scaleChildren  => 0,
+		scrollBarClass => 'Prima::ScrollBar',
+		hScrollBarProfile=>{},
+		vScrollBarProfile=>{},
 		selectable     => 1,
 		showItemHint   => 1,
 		vScroll        => 1,
@@ -127,7 +130,21 @@ sub init
 		if ( $images[0]) {
 			@imageSize = $images[0]-> size;
 		} else {
-			@imageSize = (0,0);
+			# if compiled without gif support
+			@imageSize = (11,11);
+			for my $i (0,1) {
+				$images[$i] = Prima::DeviceBitmap->new(
+					width     => $imageSize[0],
+					height    => $imageSize[1],
+					backColor => cl::White,
+					color     => cl::Gray,
+				);
+				$images[$i]->clear;
+				$images[$i]->rectangle(0,0,10,10);
+				$images[$i]->color(cl::Black);
+				$images[$i]->line( 2, 5, 8, 5 );
+			}
+			$images[1]->line( 5, 2, 5, 8);
 		}
 	}
 	for ( qw( topItem focusedItem))
@@ -141,6 +158,7 @@ sub init
 	$self-> {items}      = [];
 	my %profile = $self-> SUPER::init(@_);
 	$self-> setup_indents;
+	$self->{$_} = $profile{$_} for qw(scrollBarClass hScrollBarProfile vScrollBarProfile);
 	for ( qw( autoHScroll autoVScroll hScroll vScroll offset itemHeight autoHeight borderWidth 
 		indent items focusedItem topItem showItemHint dragable multiSelect extendedSelect))
 		{ $self-> $_( $profile{ $_}); }
