@@ -2,16 +2,15 @@ package Prima::RubberBand;
 
 use strict;
 use warnings;
-use Prima;
 
 sub new
 {
 	my ( $class, %profile ) = @_;
 	my $ref = {
-		canvas   => $::application,
-		rect     => [-1,-1,-1,-1],
-		clipRect => [-1,-1,-1,-1],
-		breadth  => 1,
+	        mode    => 'auto',  # auto, full, xor
+		canvas  => $::application,
+		rect    => [-1,-1,-1,-1],
+		breadth => 1,
 	};
 	my $self = bless $ref, shift;
 	$self-> set(%profile);
@@ -19,59 +18,14 @@ sub new
 	return $self;
 }
 
-sub _normalize_rect
-{
-	my $rect = shift;
-	($$rect[2],$$rect[0]) = ($$rect[0],$$rect[2]) if $$rect[2] < $$rect[0];
-	($$rect[3],$$rect[1]) = ($$rect[1],$$rect[3]) if $$rect[3] < $$rect[1];
-}
-
-sub _rect_changed
-{
-	my ( $a, $b ) = @_;
-	my @r1 = @$a;
-	my @r2 = @$b;
-	_normalize_rect(\@r1);
-	_normalize_rect(\@r2);
-	return
-		$r2[0] != $r1[0] ||
-		$r2[1] != $r1[1] ||
-		$r2[2] != $r1[2] ||
-		$r2[3] != $r1[3];
-}
-
 sub set
 {
 	my ( $self, %profile ) = @_;
 	my $visible = $self-> {visible};
-
-	my ($rect_changed, $other_changed);
-	if ( exists $profile{rect} ) {
-		$rect_changed = 1 if _rect_changed($profile{rect}, $self->{rect});
-	}
-	if ( exists $profile{clipRect} ) {
-		$other_changed = 1 if _rect_changed($profile{clipRect}, $self->{clipRect});
-	}
-	for my $accessor (grep { exists $profile{$_} } qw(canvas breadth)) {
-		my $old = $self->$accessor();
-		next if $old eq $profile{$accessor};
-		$other_changed = 1;
-		last;
-	}
-	$other_changed = 1 if $rect_changed and !$visible;
-	$rect_changed  = 0 if $other_changed;
-	return unless $rect_changed or $other_changed;
-
-	if ( $other_changed ) {
-		$self-> hide if $visible;
-		$self-> $_( @{$profile{$_}} ) for grep { exists $profile{$_} } qw(rect clipRect);
-		$self-> $_( $profile{$_}    ) for grep { exists $profile{$_} } qw(canvas breadth);
-		$self-> show if $visible;
-	} elsif ( $rect_changed ) {
-		$self->{visible} = 0;
-		$self->rect( @{ $profile{rect} });
-		$self->_visible(1, 1);
-	}
+	$self-> hide if $visible;
+	$self-> $_( @{$profile{$_}} ) for grep { exists $profile{$_} } qw(rect);
+	$self-> $_( $profile{$_}    ) for grep { exists $profile{$_} } qw(mode canvas breadth);
+	$self-> show if $visible;
 }
 
 sub DESTROY { shift-> hide }
@@ -88,6 +42,21 @@ sub hide
 	$self-> _visible(0) if $self-> _visible;
 }
 
+sub _gfx_mode
+{
+	my $self = shift;
+	if ( $self-> {mode} eq 'auto') {
+		return (
+			$^O =~ /win32/i && 
+			$::application-> get_system_value( sv::CompositeDisplay ) &&
+			$self-> {canvas} && 
+			$self-> {canvas}-> isa('Prima::Widget')
+		) ? 1 : 0;
+	} else {
+		return ( $self-> {mode} eq 'full' ) ? 1 : 0;
+	}
+}
+
 sub canvas
 {
 	return $_[0]-> {canvas} unless $#_;
@@ -96,6 +65,15 @@ sub canvas
 	$self-> {canvas} = $canvas // $::application;
 }
 
+sub mode
+{
+	return $_[0]-> {mode} unless $#_;
+
+	my ( $self, $mode ) = @_;
+	Carp::confess "mode(auto,full,xor)" unless $mode =~ /^(auto|full|xor)$/;
+	$self-> {mode} = $mode;
+}
+
 # geometry handlers
 
 sub left   { $_[0]-> {rect}-> [0] }
@@ -114,27 +92,11 @@ sub rect
 	my ( $self, @rect ) = @_;
 	Carp::confess("@rect") unless 4 == grep { defined } @rect;
 
-	_normalize_rect(\@rect);
+	($rect[2],$rect[0]) = ($rect[0],$rect[2]) if $rect[2] < $rect[0];
+	($rect[3],$rect[1]) = ($rect[1],$rect[3]) if $rect[3] < $rect[1];
 	@{$self-> {rect}} = @rect;
 }
 
-sub clipRect
-{
-	return @{$_[0]-> {clipRect}} unless $#_;
-
-	my ( $self, @rect ) = @_;
-	Carp::confess("@rect") unless 4 == grep { defined } @rect;
-
-	_normalize_rect(\@rect);
-	@{$self-> {clipRect}} = @rect;
-}
-
-sub has_clip_rect
-{
-	my $self = shift;
-	return 4 != grep { $_ == -1 } @{ $self->{clipRect} };
-}
-
 sub breadth
 {
 	return $_[0]-> {breadth} unless $#_;
@@ -170,7 +132,7 @@ sub _visible
 {
 	return $_[0]-> {visible} unless $#_;
 
-	my ( $self, $visible, $optimized_rect_change ) = @_;
+	my ( $self, $visible ) = @_;
 	$visible = ( $visible ? 1 : 0 );
 	my $curr_visible = ( $self-> {visible} ? 1 : 0);
 	return if $visible == $curr_visible;
@@ -179,10 +141,17 @@ sub _visible
 	$self-> {visible} = $visible;
 
 	my $canvas = $self-> {canvas};
+		
+	# just a regular xor
+	unless ( $self-> _gfx_mode ) {
+		$canvas-> rect_focus( $self-> rect, $self-> breadth );
+		return;
+	}
+
+	# save all bits under the rect
 	if ( $visible ) {
-		my @clip = $self-> has_clip_rect ?
-			$canvas-> client_to_screen( $self-> clipRect ) :
-			( 0, 0, $::application->width - 1, $::application-> height - 1 );
+		my @desktop = $::application-> size;
+		@desktop = ( 0, 0, $desktop[0] - 1, $desktop[1] - 1);
 
 		my @outer = $self-> rect;
 		my @delta = $canvas-> client_to_screen(0,0);
@@ -208,57 +177,50 @@ sub _visible
 			push @requests, [ $outer[0], $inner[1] + 1, $inner[0], $inner[3] - 1 ];
 			push @requests, [ $inner[2], $inner[1] + 1, $outer[2], $inner[3] - 1 ];
 		}
-		@requests = map { _intersect( $_, \@clip ) } @requests;
 
-		goto LEAVE unless @requests;
+		@requests = grep { _intersect( $_, \@desktop ) } @requests;
+		$self-> {_cache} = [];
 
-		_normalize_rect($_) for @requests;
-
-		unless ( $self->{_widgets} ) {
-			push @{ $self-> {_widgets} }, Prima::Widget->new(
-				origin      => [ 0, 0 ],
-				size        => [ 1, 1 ],
-				owner       => $::application,
-				color       => cl::White,
-				backColor   => cl::Black,
-				visible     => 0,
-				onPaint     => sub {
-					my ( $self, $canvas ) = @_;
-					$canvas->fillPattern(
-						($self->left % 2) ?
-							[ (0xaa, 0x55) x 4 ] :
-							[ (0x55, 0xaa) x 4 ]
-					);
-					$canvas->bar(0,0,$self->size);
-				},
-			) for 1..4;
-		}
-
-		my $i = 0;
+		return unless @requests;
+		
 		for ( @requests ) {
 			my ( $x1, $y1, $x2, $y2) = @$_;
-			my $w = $x2 - $x1 + 1;
-			my $h = $y2 - $y1 + 1;
-			$self->{_widgets}->[$i++]->set(
-				origin  => [ $x1, $y1 ],
-				size    => [ $w, $h ],
-				visible => 1,
+			push @{ $self-> {_cache} }, [
+				$x1 - $delta[0], 
+				$y1 - $delta[1], 
+				$::application-> get_image( $x1, $y1, $x2 - $x1 + 1, $y2 - $y1 + 1 )
+			];
+		}
+
+		my ( $cl, $cl2, $rop, $fp) = ( $canvas-> color, $canvas-> backColor, $canvas-> rop, $canvas-> fillPattern);
+		$canvas-> set(
+			fillPattern => fp::SimpleDots,
+			color       => cl::Set,
+			backColor   => cl::Clear,
+			rop         => rop::XorPut,
+		);
+
+		for ( @requests ) {
+			my ( $x1, $y1, $x2, $y2) = @$_;
+			$canvas-> bar(
+				$x1 + $delta[0],
+				$y1 + $delta[1],
+				$x2 + $delta[0],
+				$y2 + $delta[1]
 			);
 		}
 
-	LEAVE:
-		return unless $self->{_widgets};
-		if ( $optimized_rect_change ) {
-			for ( my $i = 0; $i < 4; $i++) {
-				$self->{_widgets}->[$i]->visible( defined $requests[$i] );
-			}
-		}
-		for ( my $i = 0; $i < 4; $i++) {
-			$self->{_widgets}->[$i]->bring_to_front;
-		}
+		$canvas-> set(
+			fillPattern => $fp,
+			backColor   => $cl2,
+			color       => $cl,
+			rop         => $rop,
+		);
 	} else {
-		return unless $self->{_widgets};
-		$_->hide for @{$self->{_widgets}};
+		# restore bits
+		# $canvas-> rectangle( $_->[0], $_-> [1], $_->[0] - 1 + $_->[2]-> width, $_[1] - 1 + $_-> [2]-> height) for @{ $self-> {_cache} };
+		$canvas-> put_image( @$_) for @{ $self-> {_cache} };
+		$self-> {_cache} = [];
 	}
 }
 
@@ -270,7 +232,7 @@ sub rubberband
 
 	if ($profile{destroy}) {
 		$self-> {__rubberband}-> hide if $self-> {__rubberband};
-		return delete $self-> {__rubberband}
+		return delete $self-> {__rubberband} 
 	}
 
 	if ( keys %profile) {
@@ -287,11 +249,13 @@ sub rubberband
 
 1;
 
+__DATA__
+
 =pod
 
 =head1 NAME
 
-Prima::RubberBand - draw rubberbands
+Prima::RubberBand - draw rubberbands 
 
 =head1 DESCRIPTION
 
@@ -305,23 +269,26 @@ thing it can do is to draw a static rubberband - but also remember the last
 coordinates drawn, so cleaning comes for free.
 
 The idea is that a rubberband object is meant to be a short-lived one: as soon
-as it get instantiated it draws itself on the screen. When it is destroyed, the
+as it get instantiatet it draws itself on the screen. When it is destroyed, the
 rubberband is erased too.
 
 =head1 SYNOPSIS
 
 	use strict;
 	use Prima qw(Application RubberBand);
-
+	
 	sub xordraw
 	{
 		my ($self, @new_rect) = @_;
-		$::application-> rubberband( @new_rect ?
+		my $o = $::application;
+		$o-> begin_paint;
+		$o-> rubberband( @new_rect ?
 			( rect => \@new_rect ) :
 			( destroy => 1 )
 		);
+		$o-> end_paint;
 	}
-
+	
 	Prima::MainWindow-> create(
 		onMouseDown => sub {
 			my ( $self, $btn, $mod, $x, $y) = @_;
@@ -339,19 +306,11 @@ rubberband is erased too.
 			$self-> capture(0);
 		},
 	);
-
+	
 	run Prima;
 
 =head1 API
 
-=over
-
-=item new %properties
-
-Creates a new RubberBand instance. See description of properties below.
-
-=back
-
 =head2 Properties
 
 =over
@@ -364,10 +323,13 @@ Defines rubberband breadth, in pixels.
 
 Sets the painting surface, and also the widget (it must be a widget) used for drawing.
 
-=item clipRect X1, Y1, X2, Y2
+=item mode STRING = 'auto'
 
-Defines the clipping rectangle, in inclusive-inclusive coordinates. If set to [-1,-1,-1,-1],
-means no clipping is done.
+The module implements two techniques, standard classic 'xor' (using .rect_focus method) 
+and a conservative method that explicitly saves and restores desktop pixels ('full').
+The 'auto' mode checks the system and selects the appropriate mode.
+
+Allowed modes: auto, xor, full
 
 =item rect X1, Y1, X2, Y2
 
@@ -384,10 +346,6 @@ is always inside these coordinates, no matter what breadth is.
 
 Hides the band, if drawn
 
-=item has_clip_rect
-
-Checks whether clipRect contains an actual clippring rectange or it is empty.
-
 =item set %profile
 
 Applies all properties
@@ -396,10 +354,6 @@ Applies all properties
 
 Same shortcuts as in C<Prima::Widget>, but read-only.
 
-=item show
-
-Show the band, if invisible
-
 =back
 
 =head1 Prima::Widget interface
@@ -448,7 +402,9 @@ application exits)"
 This quote seems to explain the effect why screen sometimes gets badly
 corrupted when using a normal xor rubberband. UCE ( Update Compatibility
 Evaluator ?? ) seems to be hacky enough to recognize some situations, but not
-all.
+all.  It seems that depending on which widget received mouse button just before
+initialting rubberband drawing matters somehow. Anyway, the module tries to
+see if we're under Windows 7 aero, and if so, turns the 'full' mode on.
 
 =cut
 
