@@ -27,7 +27,7 @@
 #     Vadim Belman   <voland@plab.ku.dk>
 #     Anton Berezin  <tobez@plab.ku.dk>
 #
-#  $Id: Utils.pm,v 1.13 2005/10/13 17:22:51 dk Exp $
+#  $Id$
 
 package Prima::Utils;
 use strict;
@@ -178,11 +178,7 @@ user interface used in the system:
 	gui::PM  
 	gui::Windows
 	gui::XLib 
-	gui::OpenLook
-	gui::Motif
-
-The meaning of the return value is somewhat vague, and
-might be deprecated in future releases.
+	gui::GTK2
 
 =item get_os
 
