@@ -1,6 +1,9 @@
+#
+#  Created by Dmitry Karasik  <dmitry@karasik.eu.org>
+#
+# $Id$
+#
 # Initializes Prima so that it skips parsing @ARGV;
-use strict;
-use warnings;
-no warnings 'once';
+
 push @Prima::preload, 'noargv';
 1;
