@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: Widget_geometry.c,v 1.6 2007/08/09 13:03:06 dk Exp $
+ * $Id$
  */
 
 #include "apricot.h"
@@ -55,7 +55,6 @@ static void Widget_place_leave( Handle self);
               geomSize request size, uses virtualSize instead.
 
    pack and place - copy-pasted from Perl-Tk.  
-   Warning - all Tk positioning code is in Tk coordinates, meaning that Y axis descends
    
   */
 
@@ -199,7 +198,7 @@ Widget_check_in( Handle self, Handle in, Bool barf)
    /* check overall validity */
    if ( !in || !kind_of( in, CWidget)) {
       if ( barf)
-         croak("%s: invalid 'in': not a widget", "RTC008F: Prima::Widget::pack");
+         croak("%s: invalid 'in': not a widget", "Prima::Widget::pack");
       else
          return nilHandle;
    }
@@ -208,7 +207,7 @@ Widget_check_in( Handle self, Handle in, Bool barf)
    while ( h) {
       if ( h == self) {
          if ( barf)
-            croak("%s: invalid 'in': is already a child", "RTC008F: Prima::Widget::pack");
+            croak("%s: invalid 'in': is already a child", "Prima::Widget::pack");
          else
             return nilHandle;
       }
@@ -220,7 +219,7 @@ Widget_check_in( Handle self, Handle in, Bool barf)
    while ( h) {
       if ( h == in) {
          if ( barf)
-            croak("%s: invalid 'in': already a pack slave", "RTC008F: Prima::Widget::pack");
+            croak("%s: invalid 'in': already a pack slave", "Prima::Widget::pack");
          else
             return nilHandle;
       }
@@ -231,7 +230,7 @@ Widget_check_in( Handle self, Handle in, Bool barf)
    while ( h) {
       if ( h == in) {
          if ( barf)
-            croak("%s: invalid 'in': already a place slave", "RTC008F: Prima::Widget::pack");
+            croak("%s: invalid 'in': already a place slave", "Prima::Widget::pack");
          else
             return nilHandle;
       }
@@ -619,7 +618,7 @@ Widget_pack_slaves( Handle self)
 		cavityHeight = 0;
 	    }
 	    frameX = cavityX;
-	    if (slavePtr-> geomInfo. side == TOP) {
+	    if (slavePtr-> geomInfo. side == BOTTOM) {
 		frameY = cavityY;
 		cavityY += frameHeight;
 	    } else {
@@ -676,13 +675,13 @@ Widget_pack_slaves( Handle self)
            break;
         }
 	switch (slavePtr-> geomInfo. anchory) {
-        case NORTH:
+        case SOUTH:
            y = frameY + borderY;
            break;
         case CENTER:
            y = frameY + (frameHeight - height)/2;
            break;
-        case SOUTH:
+        case NORTH:
            y = frameY + frameHeight - height - borderY;
            break;
         }
@@ -690,9 +689,9 @@ Widget_pack_slaves( Handle self)
         {
            Rect r;
            r. left   = x;
-           r. bottom = size. y - y - height;
+           r. bottom = y;
            r. right  = x + width;
-           r. top    = size. y - y;
+           r. top    = y + height;
 
            /* printf("%s: %d %d %d %d\n", slavePtr-> name, x, r.bottom, width, r.top); */
            slavePtr-> self-> set_rect(( Handle) slavePtr, r);
@@ -855,7 +854,7 @@ Widget_packInfo( Handle self, Bool set, SV * packInfo)
          if ( *c == 'b' && (strcmp( c, "bottom")==0)) var-> geomInfo. side = BOTTOM; else
          if ( *c == 'r' && (strcmp( c, "right")==0))  var-> geomInfo. side = RIGHT; else
          if ( *c == 't' && (strcmp( c, "top")==0))    var-> geomInfo. side = TOP; else
-            croak("%s: invalid 'side'", "RTC008F: Prima::Widget::pack");
+            croak("%s: invalid 'side'", "Prima::Widget::pack");
       }
 
       if ( pexist( fill)) {
@@ -873,7 +872,7 @@ Widget_packInfo( Handle self, Bool set, SV * packInfo)
             var-> geomInfo. fillx = 
             var-> geomInfo. filly = 1; 
          } else
-            croak("%s: invalid 'fill'", "RTC008F: Prima::Widget::pack");
+            croak("%s: invalid 'fill'", "Prima::Widget::pack");
       }
       
       if ( pexist( expand)) {
@@ -910,7 +909,7 @@ Widget_packInfo( Handle self, Bool set, SV * packInfo)
             var-> geomInfo. anchorx = CENTER;
             var-> geomInfo. anchory = CENTER;
          } else
-            croak("%s: invalid 'anchor'", "RTC008F: Prima::Widget::pack");
+            croak("%s: invalid 'anchor'", "Prima::Widget::pack");
       }
 
       if ( pexist( ipadx)) var-> geomInfo. ipad. x = pget_i( ipadx);
@@ -922,12 +921,12 @@ Widget_packInfo( Handle self, Bool set, SV * packInfo)
          SV * sv = pget_sv( after);
          if ( SvTYPE(sv) != SVt_NULL) {
             if ( !( var-> geomInfo. order = gimme_the_mate( sv)))
-               croak("%s: invalid 'after'", "RTC008F: Prima::Widget::pack");
+               croak("%s: invalid 'after'", "Prima::Widget::pack");
             var-> geomInfo. after = 1;
             if ( pexist( before)) {
                sv = pget_sv( before);
                if ( SvTYPE(sv) != SVt_NULL)
-                  croak("%s: 'after' and 'before' cannot be present simultaneously", "RTC008F: Prima::Widget::pack");
+                  croak("%s: 'after' and 'before' cannot be present simultaneously", "Prima::Widget::pack");
             }
          } else {
             var-> geomInfo. order = nilHandle;
@@ -938,7 +937,7 @@ Widget_packInfo( Handle self, Bool set, SV * packInfo)
          SV * sv = pget_sv( before);
          if ( SvTYPE(sv) != SVt_NULL) {
             if ( !( var-> geomInfo. order = gimme_the_mate( sv)))
-               croak("%s: invalid 'before'", "RTC008F: Prima::Widget::pack");
+               croak("%s: invalid 'before'", "Prima::Widget::pack");
          } else
             var-> geomInfo. order = nilHandle;
          var-> geomInfo. after = 0;
@@ -1147,21 +1146,21 @@ Widget_place_slaves( Handle self)
         }
 	switch (slavePtr-> anchory) {
         case NORTH:
+           y -= height;
            break;
         case CENTER:
 	   y -= height/2;
            break;
         case SOUTH:
-           y -= height;
            break;
         }
 
         {
            Rect r;
            r. left   = x;
-           r. bottom = size. y - y - height;
+           r. bottom = y;
            r. right  = x + width;
-           r. top    = size. y - y;
+           r. top    = y + height;
             
            /* printf("%s: %d %d %d %d\n", slave-> name, x, y, width, height); */
            slave-> self-> set_rect(( Handle) slave, r);
@@ -1250,7 +1249,7 @@ Widget_placeInfo( Handle self, Bool set, SV * placeInfo)
             var-> geomInfo. anchorx = CENTER;
             var-> geomInfo. anchory = CENTER;
          } else
-            croak("%s: invalid 'anchor'", "RTC008F: Prima::Widget::place");
+            croak("%s: invalid 'anchor'", "Prima::Widget::place");
       }
 
       if ( pexist( x)) {
