@@ -23,15 +23,14 @@
 #  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 #  SUCH DAMAGE.
 #
-#  $Id$
-#
 
-=pod 
-=item NAME
+=pod
 
-Prima button widgets
+=head1 NAME
 
-=item FEATURES
+examples/buttons2.pl - Prima button widgets
+
+=head1 FEATURES
 
 Demonstrates the variety of built-in buttons functionality.
 Note the "Bits for toolbar" button, which copies and
@@ -39,6 +38,9 @@ pastes its image into the clipboard.
 
 =cut
 
+use strict;
+use warnings;
+
 use Prima qw(Buttons StdBitmap), Application => { name => 'Buttons sample' };
 
 my $w = Prima::MainWindow-> create(
@@ -63,8 +65,8 @@ $w-> insert( Radio =>
 	hint => 'Radio!',
 );
 
-$i = Prima::StdBitmap::icon( sbmp::GlyphCancel);
-$j = Prima::StdBitmap::icon( sbmp::GlyphOK);
+my $i = Prima::StdBitmap::icon( sbmp::GlyphCancel);
+my $j = Prima::StdBitmap::icon( sbmp::GlyphOK);
 
 $w-> insert( Button =>
 	origin => [ 10, 100],
